@@ -69,6 +69,8 @@ class Core:
 
     def main(self, args=None, prog_name=None, obj=None, **extra):
         """The main entry function"""
+        from pip._internal.utils.temp_dir import global_tempdir_manager
+
         self.init_parser()
         self.load_plugins()
 
@@ -93,7 +95,8 @@ class Core:
             sys.exit(1)
         else:
             try:
-                f(options.project, options)
+                with global_tempdir_manager():
+                    f(options.project, options)
             except Exception:
                 etype, err, traceback = sys.exc_info()
                 if stream.verbosity > stream.NORMAL:
